/**
* @module @promises/do-while-parallel
* @copyright © 2017 Yisrael Eliav <yisraelx@gmail.com> (https://github.com/yisraelx)
* @license MIT
*/
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (factory((global.P = global.P || {})));
}(this, (function (exports) { 'use strict';

    function exec(fn) {
        return Promise.resolve().then(fn);
    }

    function whileParallel(test, iteratee, limit) {
        if (iteratee === void 0) { iteratee = function () { }; }
        if (limit === void 0) { limit = Infinity; }
        limit--;
        return new Promise(function (resolve, reject) {
            var count = 0;
            var completed = 0;
            var isStop = false;
            var onReject = function (error) {
                isStop = true;
                reject(error);
            };
            var each = function () {
                if (isStop) {
                    if (count === completed) {
                        resolve();
                    }
                }
                else {
                    exec(test).then(function (isPass) {
                        if (isPass && !isStop) {
                            count++;
                            exec(iteratee).then(function () {
                                completed++;
                                if (limit <= 0 || isStop) {
                                    each();
                                }
                            }).catch(onReject);
                            if (limit > 0) {
                                limit--;
                                each();
                            }
                        }
                        else {
                            isStop = true;
                            each();
                        }
                    }).catch(onReject);
                }
            };
            each();
        });
    }

    function doWhileParallel(test, iteratee, limit) {
        if (iteratee === void 0) { iteratee = function () { }; }
        if (limit === void 0) { limit = Infinity; }
        limit--;
        if (limit <= 0) {
            return exec(iteratee).then(function () {
                return whileParallel(test, iteratee, limit);
            });
        }
        else {
            return Promise.all([
                exec(iteratee),
                whileParallel(test, iteratee, limit)
            ]).then(function () { });
        }
    }

    exports.default = doWhileParallel;

    Object.defineProperty(exports, '__esModule', { value: true });

    exports.doWhileParallel = exports.default;

})));
//# sourceMappingURL=bundle.umd.js.map
