"use strict";
/**
 * @module @promises/do-while-parallel
 * @copyright © 2017 Yisrael Eliav <yisraelx@gmail.com> (https://github.com/yisraelx)
 * @license MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
var exec_1 = require("@promises/exec");
var while_parallel_1 = require("@promises/while-parallel");
/**
 * @function
 * @example
 *
 *  let index: number = 0;
 *
 *  whileParallel(() => {
 *    console.log(`test ${index}`);
 *    return index++ < 3;
 *  }, () => {
 *    let thisIndex = index;
 *    return timeout((resolve) => {
 *     console.log(`iteratee ${thisIndex}`);
 *     resolve();
 *    }, 4 - index);
 *  }).then(() => {
 *    console.log('completed');
 *  });
 *
 *  // => 'test 0'
 *  // => 'test 1'
 *  // => 'test 2'
 *  // => 'test 3'
 *  // => 'iteratee 3'
 *  // => 'iteratee 2'
 *  // => 'iteratee 1'
 *  // => 'iteratee 0'
 *  // => 'completed'
 */
function doWhileParallel(test, iteratee, limit) {
    if (iteratee === void 0) { iteratee = function () { }; }
    if (limit === void 0) { limit = Infinity; }
    limit--;
    if (limit <= 0) {
        return exec_1.default(iteratee).then(function () {
            return while_parallel_1.default(test, iteratee, limit);
        });
    }
    else {
        return Promise.all([
            exec_1.default(iteratee),
            while_parallel_1.default(test, iteratee, limit)
        ]).then(function () { });
    }
}
exports.default = doWhileParallel;
//# sourceMappingURL=index.js.map